@@ -153,7 +153,7 @@ def freq(word_distribution,top_n=None, words=None, graph=True):
         for word in words:
             y.append(concept_freq_total[word]/total_news)
         plt.bar(words,y)
-        plt.tittle("term frecuency bar graph")
+        plt.title("term frecuency bar graph")
         
         
 
